package com.chenyang.nse.bussiness.service.core;

import com.chenyang.nse.bussiness.entity.orm.table.core.duty.DutyTableInfo;
import com.chenyang.nse.bussiness.entity.orm.table.core.duty.FieldPermissionsInfo;
import com.chenyang.nse.bussiness.entity.orm.table.core.duty.UserJoinFieldInfo;
import java.util.List;

public interface DutyUserService {
   void saveDutyTableInfo(DutyTableInfo dutyTableInfo);

   void saveUserJoinFieldInfo(UserJoinFieldInfo userJoinFieldInfo);

   void saveFieldPermissionsInfo(FieldPermissionsInfo fieldPermissionsInfo);

   void removeUserJoinFieldInfo(String dutytableid);

   void removefieldPermissionsInfo(String dutytableid, String joinid);

   DutyTableInfo queryDutyTableById(String id);

   void updateDutyTableInfo(DutyTableInfo dutyTableInfo);

   List<DutyTableInfo> queryExists(String datasystemid, String schemaname, String tablename, String projectid);

   List<UserJoinFieldInfo> queryUserJoinFieldInfo(String dutytableid, String joinid);

   List<FieldPermissionsInfo> queryFieldPermissionsInfo(String id);

   void updateFieldInfo(String dutytableid, String column, String businessid, String skillid);

   List<FieldPermissionsInfo> queryFieldAll(String dutytableid, String column);
}
